# ChallengeAnswerSpec

The contents of the challenge answer. 
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**answer** | **str** | An opaque string used to answer the challenge. | 
**challenge_id** | **str** | The id of the challenge being answered. This is not required. It is present for consistency.  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


